==> apache-inlong-1.12.0-src.tar.gz: apache-inlong-1.12.0/inlong-agent/agent-plugins/src/main/java/org/apache/inlong/agent/plugin/task/CronTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.task;

import org.apache.inlong.agent.conf.TaskProfile;
import org.apache.inlong.agent.db.Db;
import org.apache.inlong.agent.plugin.file.Task;

/**
 * Generate job by crontab expression.
 */
public class CronTask extends Task {

    @Override
    public void init(Object srcManager, TaskProfile profile, Db basicDb) {

    }

    @Override
    public void run() {

    }

    @Override
    public void destroy() {

    }

    @Override
    public TaskProfile getProfile() {
        return null;
    }

    @Override
    public String getTaskId() {
        return null;
    }

    @Override
    public boolean isProfileValid(TaskProfile profile) {
        return true;
    }

    @Override
    public void addCallbacks() {

    }
}

==> apache-inlong-2.1.0-src.tar.gz: apache-inlong-2.1.0/inlong-agent/agent-plugins/src/main/java/org/apache/inlong/agent/plugin/task/CronTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.task;

import org.apache.inlong.agent.conf.TaskProfile;
import org.apache.inlong.agent.plugin.file.Task;
import org.apache.inlong.agent.store.Store;

/**
 * Generate job by crontab expression.
 */
public class CronTask extends Task {

    @Override
    public void init(Object srcManager, TaskProfile profile, Store basicStore) {

    }

    @Override
    public void run() {

    }

    @Override
    public void destroy() {

    }

    @Override
    public TaskProfile getProfile() {
        return null;
    }

    @Override
    public String getTaskId() {
        return null;
    }

    @Override
    public boolean isProfileValid(TaskProfile profile) {
        return true;
    }

    @Override
    public void addCallbacks() {

    }
}
